<!--
  Filename: print-html.xsl
  Author:  Vadim Kurland
  Build date: 04/21/2001
  
  $Id  $

  Description: translates fwbuilder data file into html presentation,
               suitable for publishing on the web or printing
-->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fwbuilder="http://www.crocodile.org/~vadim/fwbuilder/1.0/"
    version="1.0"
>

<xsl:output method="html"/>
<xsl:param name="PrintFrom"/>

<xsl:strip-space elements="*"/>

<xsl:template match="ObjectRef|ServiceRef|IntervalRef" mode="rule-element">
<xsl:variable name="ptr" select="@ref"/>
<xsl:for-each select="id($ptr)">
<xsl:value-of select="@name"/>
</xsl:for-each>
<br></br>
</xsl:template>

<xsl:template match="Option" mode="prule"></xsl:template>

<xsl:template match="OSrc" mode="nrule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="ODst" mode="nrule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="OSrv" mode="nrule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="TSrc" mode="nrule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="TDst" mode="nrule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="TSrv" mode="nrule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="Src" mode="prule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="Dst" mode="prule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="Srv" mode="prule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>

<xsl:template match="When" mode="prule">
<td>
<xsl:apply-templates mode="rule-element"/>
</td>
</xsl:template>


<xsl:template match="NATRule" mode="fw">
<tr>
<td><xsl:value-of select="@position"/></td>
<xsl:apply-templates mode="nrule"/>
</tr>
</xsl:template>

<xsl:template match="PolicyRule" mode="fw">
<tr>
<td><xsl:value-of select="@position"/></td>
<xsl:apply-templates mode="prule"/>
<td><xsl:value-of select="@action"/></td>
<td>
<xsl:choose>
<xsl:when test="@log='True'">
Log
</xsl:when>
<xsl:otherwise>.</xsl:otherwise>
</xsl:choose>
</td>
<td>
<xsl:choose>
<xsl:when test="@comment">
<xsl:value-of select="@comment"/>
</xsl:when>
<xsl:otherwise>.</xsl:otherwise>
</xsl:choose>
</td>
</tr>
</xsl:template>

<xsl:template match="NAT" mode="fw">
<H2>NAT rules</H2><br></br>
<table border="1" width="90%" cellspacing="0" cellpadding="4">
<tr>
<th width="20" bgcolor="#009900"><font color="#ffffff">Num</font></th>
<th bgcolor="#009900"><font color="#ffffff">OSrc</font></th>
<th bgcolor="#009900"><font color="#ffffff">ODst</font></th>
<th bgcolor="#009900"><font color="#ffffff">OSrv</font></th>
<th bgcolor="#009900"><font color="#ffffff">TSrc</font></th>
<th bgcolor="#009900"><font color="#ffffff">TDst</font></th>
<th bgcolor="#009900"><font color="#ffffff">TSrv</font></th>
</tr>
<xsl:apply-templates mode="fw"/>
</table>
</xsl:template>

<xsl:template match="Policy" mode="fw">
<H2>Policy rules</H2><br></br>
<table border="1" width="90%" cellspacing="0" cellpadding="4">
<tr>
<th width="20" bgcolor="#009900"><font color="#ffffff">Num</font></th>
<th bgcolor="#009900"><font color="#ffffff">Src</font></th>
<th bgcolor="#009900"><font color="#ffffff">Dst</font></th>
<th bgcolor="#009900"><font color="#ffffff">Srv</font></th>
<th bgcolor="#009900"><font color="#ffffff">Time</font></th>
<th bgcolor="#009900"><font color="#ffffff">Action</font></th>
<th bgcolor="#009900"><font color="#ffffff">Logging</font></th>
<th bgcolor="#009900"><font color="#ffffff">Comment</font></th>
</tr>
<xsl:apply-templates mode="fw"/>
</table>
</xsl:template>



<xsl:template match="Firewall" mode="fw">
<hr></hr>
<i><b>
Name:     <xsl:value-of select="@name"/><br></br>
Address:  <xsl:value-of select="@address"/><br></br>
Platform: <xsl:value-of select="@platform"/><br></br>
Comment:  <xsl:value-of select="@comment"/><br></br>
</b></i><br></br>
<xsl:apply-templates select="Policy" mode="fw"/>
<xsl:apply-templates select="NAT"    mode="fw"/>
<br></br>
</xsl:template>


<xsl:template match="fwbuilder:*">
<html>
<head>
</head>
<body bgcolor="#ffffff" link="#0000ee" vlink="#551a8b" alinlk="#0000ee">

  <xsl:choose>
    <xsl:when test="id($PrintFrom)">
      <xsl:apply-templates select="id($PrintFrom)" mode="fw"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select="/FWObjectDatabase/ObjectGroup/Firewall" 
	mode="fw"/>
    </xsl:otherwise>
  </xsl:choose>

</body>
</html>
</xsl:template>

<!--
<xsl:template match="/">
<html>
<head>
</head>
<body bgcolor="#ffffff" link="#0000ee" vlink="#551a8b" alinlk="#0000ee">
<xsl:apply-templates select="/FWObjectDatabase/ObjectGroup/Firewall"/>
</body>
</html>
</xsl:template>
-->

</xsl:stylesheet>





