<!--
  Filename: policy-text.xsl
  Author:  Vadim Kurland
  Build date: 04/23/2001
  
  $Id  $

  Description: translates fwbuilder data file into plain text presentation
               suitable for printing
-->


<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fwbuilder="http://www.crocodile.org/~vadim/fwbuilder/1.0/"
    version="1.0"
>

<xsl:output method="text"/>
<xsl:strip-space elements="*"/>

<xsl:param name="PrintFrom"/>

<xsl:include href="print-policy.xs1"/>
<xsl:include href="print-nat.xs1"/>

<!-- 
*******************************************************************
* This template finds node in the list with maximum number
* of children nodes
*******************************************************************
-->

<xsl:template name="max_children">
  <xsl:param name="list"/>
  <xsl:param name="max_c"/>
  <xsl:param name="max_n" select="0"/>

  <xsl:choose>
    <xsl:when test="count($list) = 0">
      <xsl:value-of select="name($max_c)"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:variable name="n1" select="count($list[1]/*)"/>
      <xsl:choose>
        <xsl:when test="$n1 > $max_n">
          <xsl:call-template name="max_children">
	    <xsl:with-param name="list"  select="$list[position()!=1]"/>
	    <xsl:with-param name="max_c" select="$list[1]"/>
	    <xsl:with-param name="max_n" select="$n1"/>
	  </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
	  <xsl:call-template name="max_children">
	    <xsl:with-param name="list"  select="$list[position()!=1]"/>
            <xsl:with-param name="max_c" select="$max_c"/>
	    <xsl:with-param name="max_n" select="$max_n"/>
	  </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="Option"></xsl:template>
<xsl:template match="FirewallOptions"></xsl:template>
<xsl:template match="PolicyRuleOptions"></xsl:template>

<xsl:template match="ObjectRef|ServiceRef|IntervalRef" mode="rule-element">
<xsl:for-each select="id(@ref)">
<xsl:value-of select="@name"/>
</xsl:for-each>
</xsl:template>

<xsl:template match="Src|Dst|Srv" mode="obj">
  <xsl:if test="@neg='True'">! </xsl:if>
</xsl:template>



<xsl:template match="ObjectRef|ServiceRef|IntervalRef" mode="obj">
  <xsl:for-each select="id(@ref)">
    <xsl:value-of select="@name"/>
  </xsl:for-each>
</xsl:template>



<xsl:template match="Firewall" mode="fw">

Name:     <xsl:value-of select="@name"/>  
Address:  <xsl:value-of select="@address"/>
Platform: <xsl:value-of select="@platform"/>
Comment:  <xsl:value-of select="@comment"/>
-----------------------------------------------------------------
<xsl:apply-templates select="Interface/InterfacePolicy" mode="fw"/>
<xsl:apply-templates select="Policy"                    mode="fw"/>
<xsl:apply-templates select="NAT"                       mode="fw"/>
</xsl:template>


<xsl:template match="fwbuilder:*">

  <xsl:choose>
    <xsl:when test="id($PrintFrom)">
      <xsl:apply-templates select="id($PrintFrom)" mode="fw"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select="/FWObjectDatabase/ObjectGroup/Firewall" 
	mode="fw"/>
    </xsl:otherwise>
  </xsl:choose>

</xsl:template>

</xsl:stylesheet>




